==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Neįmanoma įkelti ankstesnio žaidimo. Bus pradėtas naujas žaidimas.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 praėjo</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 padaryti žingsniai</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>Liko %1 iš %2 objektų</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzė</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Parinktis</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Medžioti ir užmušti</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Skrupulingas</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Pasikartojanti apylanka</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Dėklas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>2 Dėklas</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>3 Dėklas</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>4 Dėklas</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>5 Dėklas</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmas:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Objektų:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dydis:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Medžioti ir užmušti</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Pasikartojanti apylanka</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Dėklas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>2 Dėklas</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>3 Dėklas</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>4 Dėklas</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>5 Dėklas</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze taškai</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vardas</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Surinkta taškų</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Laikas</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Žingsnių</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmas</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Sveikinimai!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Dėl surinktų taškų skaičiaus, patekote į pirmą dešimtuką.
Prašome įrašyti savo vardą:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Žaidimas</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Rodyti kur esate buvę</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Rodyti padarytų žingsnių skaičių</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Rodyti prabėgusį laiką</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Glotnūs judesiai</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Valdymas</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Judėti aukštyn:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Judėti žemyn:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Judėti kairėn:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Judėti dešinėn:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Perjungti vėliavą:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temos</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Pasirinkite temos failą</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nepavyko sukurti duomenų aplanko.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nepavyko nukopijuoti temos failo.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Šalinti pasirinktą temą?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Neįmanoma pašalinti pasirinktos temos.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Rodinys</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzė</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Užuomina</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Rekordai</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Išeiti</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>D&amp;idinti</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Mažinti</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos ka&amp;lba</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Nuos&amp;tatos</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Iš viršaus į apačią labirintų žaidimas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Piktogramos yra iš &lt;a href=%1&gt;Oxygen&lt;/a&gt; temos</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Panaudota pagal &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.5.orig.tar.gz: cutemaze-1.2.5/translations/cutemaze_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Neįmanoma įkelti ankstesnio žaidimo. Bus pradėtas naujas žaidimas.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 praėjo</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 padaryti žingsniai</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>Liko %1 iš %2 objektų</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzė</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Parinktis</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Medžioti ir užmušti</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Skrupulingas</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Pasikartojanti apylanka</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Dėklas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>2 Dėklas</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>3 Dėklas</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>4 Dėklas</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>5 Dėklas</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmas:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Objektų:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dydis:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Medžioti ir užmušti</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Pasikartojanti apylanka</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Dėklas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>2 Dėklas</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>3 Dėklas</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>4 Dėklas</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>5 Dėklas</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze taškai</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vardas</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Surinkta taškų</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Laikas</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Žingsnių</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmas</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Sveikinimai!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Dėl surinktų taškų skaičiaus, patekote į pirmą dešimtuką.
Prašome įrašyti savo vardą:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Žaidimas</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Rodyti kur esate buvę</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Rodyti padarytų žingsnių skaičių</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Rodyti prabėgusį laiką</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Glotnūs judesiai</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Valdymas</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Judėti aukštyn:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Judėti žemyn:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Judėti kairėn:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Judėti dešinėn:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Perjungti vėliavą:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temos</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Pasirinkite temos failą</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nepavyko sukurti duomenų aplanko.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nepavyko nukopijuoti temos failo.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Klausimas</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Šalinti pasirinktą temą?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Neįmanoma pašalinti pasirinktos temos.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>Rodyti užuominą:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Rodinys</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzė</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Užuomina</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Rekordai</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Išeiti</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>D&amp;idinti</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Mažinti</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos ka&amp;lba</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Nuos&amp;tatos</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Iš viršaus į apačią labirintų žaidimas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Piktogramos yra iš &lt;a href=%1&gt;Oxygen&lt;/a&gt; temos</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Panaudota pagal &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licenciją</translation>
    </message>
</context>
</TS>
